Crate cargo_vendor_filterer

Crate cargo_vendor_filterer 

Constants

CARGO_CHECKSUM
The filename cargo writes in packages with file checksums
CARGO_TOML
The name of the Cargo.toml file
CONFIG_KEY
The path we use in Cargo.toml i.e. package.metadata.vendor-filter
LIB
The well-known cargo target for a library
MANIFEST_KEY_PACKAGE
The package entry
OFFLINE
The CLI argument passed to cargo to work offline
RESPECT_SOURCE_CONFIG
The CLI argument passed to cargo vendor to respect override of the crates.io source when downloading crates
SELF_NAME
The name of our binary
SYNC
The CLI argument passed to cargo to work with multiple Cargo.toml-files
UNWANTED_MANIFEST_KEYS
Extra targets which we need to remove because Cargo validates them and will error out when we’ve replaced the library with a stub.
UNWANTED_PACKAGE_KEYS
Cargo also checks these keys in the package section
VENDOR_DEFAULT_PATH
The default directory path
VENDOR_DEFAULT_PATH_TAR
The default path for –format=tar
VENDOR_DEFAULT_PATH_TAR_GZ
The default path for –format=tar.gz
VENDOR_DEFAULT_PATH_TAR_ZSTD
The default path for –format=tar.zstd
VERSIONED_DIRS
The CLI argument passed to cargo vendor to always include version in subdir name