Constants
- CARGO_
CHECKSUM - The filename cargo writes in packages with file checksums
- CARGO_
TOML - The name of the Cargo.toml file
- CONFIG_
KEY - The path we use in Cargo.toml i.e.
package.metadata.vendor-filter - LIB
- The well-known cargo target for a library
- MANIFEST_
KEY_ PACKAGE - The package entry
- OFFLINE
- The CLI argument passed to cargo to work offline
- RESPECT_
SOURCE_ CONFIG - The CLI argument passed to
cargo vendorto respect override of thecrates.iosource when downloading crates - SELF_
NAME - The name of our binary
- SYNC
- The CLI argument passed to cargo to work with multiple Cargo.toml-files
- UNWANTED_
MANIFEST_ KEYS - Extra targets which we need to remove because Cargo validates them and will error out when we’ve replaced the library with a stub.
- UNWANTED_
PACKAGE_ KEYS - Cargo also checks these keys in the package section
- VENDOR_
DEFAULT_ PATH - The default directory path
- VENDOR_
DEFAULT_ PATH_ TAR - The default path for –format=tar
- VENDOR_
DEFAULT_ PATH_ TAR_ GZ - The default path for –format=tar.gz
- VENDOR_
DEFAULT_ PATH_ TAR_ ZSTD - The default path for –format=tar.zstd
- VERSIONED_
DIRS - The CLI argument passed to
cargo vendorto always include version in subdir name